===========================
Changes in version 2016.2.0
===========================

Instant 2016.2.0 was released on 2016-11-30.

- Add Python version string to hash signature input
- Add pipelines testing, with py2 and py3 coverage
- Remove commands module (removed from Py3)
- Switch unit tests to pytest
